@@ -134,9 +134,9 @@ calculateP2G <- function(peakMatrix = NULL,
   if (!gene_symbol %in% colnames(rowData(expMatrix))) {
     stop("rowData of expMatrix does not contain ", gene_symbol)
   }
-  if(is(cellNum, "CellNumSol") && as.list(sys.call(sys.nframe()-1))[[1]]!="optimizeMetacellNumber"){
-    message("Value of the paramater 'cellNum' has not been optimized.
-                Consider running function 'optimizeMetacellNumber' and use output to set 'cellNum'")
+  if(!is(cellNum, "CellNumSol") && as.list(sys.call(sys.nframe()-1))[[1]]!="optimizeMetacellNumber"){
+    message(strwrap("Value of the paramater 'cellNum' has not been optimized.
+                Consider running function 'optimizeMetacellNumber' and use output to set 'cellNum'."))
   }
   if(is(cellNum,"CellNumSol")){
     if (cellNum@args$cor_method != cor_method){
@@ -520,7 +520,7 @@ optimizeMetacellNumber <- function(peakMatrix,
   kNum <- round(n_cells/evaluation_points^2)
 
   if (max(kNum) > 2000) {
-    warning("Max number of metacells is ", max(kNum), ". Consider increasing the number of CellNumMin to reduce the number of metacells")
+    warning(paste(c("Max number of metacells is ", max(kNum), ". Consider increasing the number of CellNumMin to reduce the number of metacells"), collapse=""))
   }
   evaluation_points <- evaluation_points[!duplicated(kNum)]
   if(length(evaluation_points)<3){
@@ -635,13 +635,13 @@ optimizeMetacellNumber <- function(peakMatrix,
   }
   if(estimation_issue){
     # TO DO: reference to the on-line documentation
-    message(c(strwrap("An issue detected during estimation optimal number of metacells.
-                        Consider at least one of the following actions:"),
+    message(paste(c(strwrap(paste(c("An issue detected during estimation optimal number of metacells.",
+                            "Consider at least one of the following actions:"), collapse=" ")),
               "1. Change of the `cellNumMin` and `cellNumMax` paramaters",
               "2. Increasing the number of evaluation points (`n_evaluation_points` argument)",
               "3. Increasing the number of iterations (`n_iter` argument)",
               strwrap("4. Increasing the number of false connections used to compute
-                        p-value null distribution (`nRandConns` argument)")))
+                        p-value null distribution (`nRandConns` argument)")), collapse="\n"))
     message("Solution not found using quadratic regression. Using cluster size with the lowest mean p-value.")
     sol <- evaluation_points[which.min(areas)]
   }
